@@ -8,17 +8,15 @@ from .building import Building
 from .context import ContextShade
 from .projection import meters_to_long_lat_factors, polygon_to_lon_lat, \
     origin_long_lat_from_location
+import dragonfly.writer.model as writer
 
 from honeybee.model import Model as hb_model
-from honeybee.shade import Shade
-from honeybee.boundarycondition import Surface
-from honeybee.typing import float_in_range, float_positive
+from honeybee.typing import float_positive
 from honeybee.config import folders
 
-from ladybug_geometry.geometry2d.pointvector import Vector2D, Point2D
+from ladybug_geometry.geometry2d.pointvector import Point2D
 from ladybug.futil import preparedir
 
-import math
 import os
 import json
 
@@ -52,7 +50,6 @@ class Model(_BaseGeometry):
     Properties:
         * identifier
         * display_name
-        * north_vector
         * units
         * tolerance
         * angle_tolerance
@@ -60,6 +57,15 @@ class Model(_BaseGeometry):
         * context_shades
         * stories
         * room_2ds
+        * average_story_count
+        * average_story_count_above_ground
+        * average_height
+        * average_height_above_ground
+        * footprint_area
+        * floor_area
+        * exterior_wall_area
+        * exterior_aperture_area
+        * volume
         * min
         * max
         * user_data
@@ -189,6 +195,62 @@ class Model(_BaseGeometry):
                      for story in building._unique_stories
                      for room2d in story._room_2ds)
 
+    @property
+    def average_story_count(self):
+        """Get the average number of stories for the buildings in the model.
+
+        Note that this will be a float and not an integer in most cases.
+        """
+        return sum([bldg.story_count for bldg in self._buildings]) / len(self._buildings)
+
+    @property
+    def average_story_count_above_ground(self):
+        """Get the average number of above-ground stories for the buildings in the model.
+
+        Note that this will be a float and not an integer in most cases.
+        """
+        return sum([bldg.story_count_above_ground for bldg in self._buildings]) / \
+            len(self._buildings)
+
+    @property
+    def average_height(self):
+        """Get the average height of the Buildings as an absolute Z-coordinate."""
+        return sum([bldg.height for bldg in self._buildings]) / len(self._buildings)
+
+    @property
+    def average_height_above_ground(self):
+        """Get the average building height relative to the first floor above ground."""
+        return sum([bldg.height_above_ground for bldg in self._buildings]) / \
+            len(self._buildings)
+
+    @property
+    def footprint_area(self):
+        """Get a number for the total footprint area of all Buildings in the Model."""
+        return sum([bldg.footprint_area for bldg in self._buildings])
+
+    @property
+    def floor_area(self):
+        """Get a number for the total floor area of all Buildings in the Model."""
+        return sum([bldg.floor_area for bldg in self._buildings])
+
+    @property
+    def exterior_wall_area(self):
+        """Get a number for the total exterior wall area for all Buildings in the Model.
+        """
+        return sum([bldg.exterior_wall_area for bldg in self._buildings])
+
+    @property
+    def exterior_aperture_area(self):
+        """Get a number for the total exterior aperture area for all Buildings.
+        """
+        return sum([bldg.exterior_aperture_area for bldg in self._buildings])
+
+    @property
+    def volume(self):
+        """Get a number for the volume of all the Buildings in the Model.
+        """
+        return sum([bldg.volume for bldg in self._buildings])
+
     @property
     def min(self):
         """Get a Point2D for the min bounding rectangle vertex in the XY plane.
@@ -211,7 +273,7 @@ class Model(_BaseGeometry):
         """Add another Dragonfly Model object to this one."""
         assert isinstance(other_model, Model), \
             'Expected Dragonfly Model. Got {}.'.format(type(other_model))
-        self._buildings =  self._buildings + other_model._buildings
+        self._buildings = self._buildings + other_model._buildings
         self._context_shades = self._context_shades + other_model._context_shades
 
     def add_building(self, obj):
@@ -222,7 +284,7 @@ class Model(_BaseGeometry):
     def add_context_shade(self, obj):
         """Add a ContextShade object to the model."""
         assert isinstance(obj, ContextShade), \
-                'Expected ContextShade. Got {}.'.format(type(obj))
+            'Expected ContextShade. Got {}.'.format(type(obj))
         self._context_shades.append(obj)
 
     def buildings_by_identifier(self, identifiers):
@@ -309,8 +371,8 @@ class Model(_BaseGeometry):
     def convert_to_units(self, units='Meters'):
         """Convert all of the geometry in this model to certain units.
 
-        Thins involves both scaling the geometry and changing the Model's
-        units property.
+        This involves scaling the geometry, scaling the Model tolerance, and
+        changing the Model's units property.
 
         Args:
             units: Text for the units to which the Model geometry should be
@@ -327,6 +389,7 @@ class Model(_BaseGeometry):
             scale_fac2 = hb_model.conversion_factor_to_meters(units)
             scale_fac = scale_fac1 / scale_fac2
             self.scale(scale_fac)
+            self.tolerance = self.tolerance * scale_fac
             self.units = units
 
     def check_duplicate_building_identifiers(self, raise_exception=True):
@@ -402,7 +465,7 @@ class Model(_BaseGeometry):
                 the results. If None, all other buildings will be included as context
                 shade in each and every Model. Set to 0 to exclude all neighboring
                 buildings from the resulting models. Default: None.
-            use_multiplier: If True, the multipliers on this Building's Stories will be
+            use_multiplier: If True, the multipliers on this Model's Stories will be
                 passed along to the generated Honeybee Room objects, indicating the
                 simulation will be run once for each unique room and then results
                 will be multiplied. If False, full geometry objects will be written
@@ -436,7 +499,7 @@ class Model(_BaseGeometry):
                         model.add_shade(shd)
         else:
             raise ValueError('Unrecognized object_per_model input: '
-                            '{}'.format(object_per_model))
+                             '{}'.format(object_per_model))
 
         # change the tolerance and units systems to match the dragonfly model
         for model in models:
@@ -445,28 +508,24 @@ class Model(_BaseGeometry):
             model.angle_tolerance = self.angle_tolerance
 
         # transfer Model extension attributes to the honeybee models
-        for hb_model in models:
-            hb_model._properties = self.properties.to_honeybee(hb_model)
+        for h_model in models:
+            h_model._properties = self.properties.to_honeybee(h_model)
 
         return models
-    
-    def to_geojson_dict(self, location, point=Point2D(0, 0), folder=None, tolerance=0.01):
+
+    def to_geojson_dict(self, location, point=Point2D(0, 0), tolerance=0.01):
         """Convert Dragonfly Model to a geoJSON-style Python dictionary.
 
         This dictionary can be written into a JSON, which is then a valid geoJSON
         that can be visualized in any geoJSON viewer. Each dragonfly Building
-        will appear in the geoJSON as a single feature.
+        will appear in the geoJSON as a single feature (either as a Polygon or
+        a MultiPolygon).
 
         Args:
             location: A ladybug Location object possessing longitude and latitude data.
             point: A ladybug_geometry Point2D for where the location object exists
                 within the space of a scene. The coordinates of this point are
                 expected to be in the units of this Model. (Default: (0, 0)).
-            folder: Text for the full path to the folder where the OpenStudio
-                model files for each building are written. This will be used
-                to specify URBANopt detailed_model_filename keys for each feature
-                within the dictionary. If None, the honeybee default simulation
-                folder will be used (Default: None).
             tolerance: The minimum distance between points at which they are
                 not considered touching. Default: 0.01, suitable for objects
                 in meters.
@@ -475,22 +534,28 @@ class Model(_BaseGeometry):
             A Python dictionary in a geoJSON style with each Building in the Model
             as a separate feature.
         """
-        # set the default simulation folder
-        if folder is None:
-            folder = folders.default_simulation_folder
-        else:
-            assert os.path.isdir(folder), \
-                'No such directory has been found on this machine: {}'.format(folder)
-
-        # set up the base dictionary for the geoJSON and default folder
+        # set up the base dictionary for the geoJSON
         geojson_dict = {'type': 'FeatureCollection', 'features': [], 'mappers': []}
-        geojson_dict['project'] = {'name': self.display_name, 'id': self.identifier}
+
+        # assign the site information in the project key
+        project_dict = {
+            'id': self.identifier,
+            'name': self.display_name,
+            'city': location.city,
+            'country': location.country,
+            'elevation': location.elevation,
+            'latitude': location.latitude,
+            'longitude': location.longitude,
+            'time_zone': location.time_zone
+        }
+        geojson_dict['project'] = project_dict
 
         # ensure that the Model we are working with is in meters
         model = self
         if self.units != 'Meters':
-            model = self.duplicate()
+            model = self.duplicate()  # duplicate to avoid editing this object
             model.convert_to_units('Meters')
+            point = point.scale(hb_model.conversion_factor_to_meters(self.units))
 
         # get the conversion factors over to (longitude, latitude)
         origin_lon_lat = origin_long_lat_from_location(location, point)
@@ -499,7 +564,7 @@ class Model(_BaseGeometry):
         # export each building as a feature in the file
         for i, bldg in enumerate(model.buildings):
             # create the base dictionary
-            feature_dict = {'geometry':{}, 'properties': {}, 'type': 'Feature'}
+            feature_dict = {'geometry': {}, 'properties': {}, 'type': 'Feature'}
 
             # add the geometry including coordinates
             footprint = bldg.footprint(tolerance)
@@ -523,9 +588,11 @@ class Model(_BaseGeometry):
             feature_dict['properties']['id'] = bldg.identifier
             feature_dict['properties']['name'] = bldg.display_name
             feature_dict['properties']['number_of_stories'] = bldg.story_count
+            feature_dict['properties']['number_of_stories_above_ground'] = \
+                bldg.story_count_above_ground
+            feature_dict['properties']['maximum_roof_height'] = \
+                bldg.height_above_ground
             feature_dict['properties']['type'] = 'Building'
-            feature_dict['properties']['detailed_model_filename'] = \
-                os.path.join(folder, bldg.identifier, 'OpenStudio', 'run', 'in.osm')
 
             # append the feature to the global dictionary
             geojson_dict['features'].append(feature_dict)
@@ -568,7 +635,7 @@ class Model(_BaseGeometry):
             preparedir(folder, remove_content=False)
 
         # get the geojson dictionary
-        geojson_dict = self.to_geojson_dict(location, point, folder, tolerance)
+        geojson_dict = self.to_geojson_dict(location, point, tolerance)
 
         # write out the dictionary to a geojson file
         project_folder = os.path.join(folder, self.identifier)
@@ -609,6 +676,14 @@ class Model(_BaseGeometry):
 
         return base
 
+    @property
+    def to(self):
+        """Model writer object.
+
+        Use this method to access Writer class to write the model in other formats.
+        """
+        return writer
+
     @staticmethod
     def _geojson_coordinates(face3d, origin_lon_lat, convert_facs):
         """Convert a horizontal Face3D to geoJSON coordinates."""
