@@ -5,10 +5,11 @@ from __future__ import division
 from ._base import _BaseGeometry
 from .properties import StoryProperties
 from .room2d import Room2D
+import dragonfly.writer.story as writer
 
 from honeybee.typing import float_positive, int_in_range, clean_string
-from honeybee.boundarycondition import Surface
-from honeybee.model import Model
+from honeybee.boundarycondition import boundary_conditions as bcs
+from honeybee.boundarycondition import Outdoors, Surface
 
 from ladybug_geometry.geometry3d.pointvector import Vector3D
 from ladybug_geometry.geometry3d.polyline import Polyline3D
@@ -39,10 +40,11 @@ class Story(_BaseGeometry):
         * parent
         * has_parent
         * floor_height
-        * volume
         * floor_area
         * exterior_wall_area
         * exterior_aperture_area
+        * volume
+        * is_above_ground
         * min
         * max
         * user_data
@@ -183,14 +185,6 @@ using-multipliers-zone-and-or-window.html
         """
         return min([room.floor_height for room in self._room_2ds])
 
-    @property
-    def volume(self):
-        """Get a number for the volume of all the Rooms in the Story.
-
-        Note that this property is for one story and does NOT use the multiplier.
-        """
-        return sum([room.volume for room in self._room_2ds])
-
     @property
     def floor_area(self):
         """Get a number for the total floor area in the Story.
@@ -215,6 +209,27 @@ using-multipliers-zone-and-or-window.html
         """
         return sum([room.exterior_aperture_area for room in self._room_2ds])
 
+    @property
+    def volume(self):
+        """Get a number for the volume of all the Rooms in the Story.
+
+        Note that this property is for one story and does NOT use the multiplier.
+        """
+        return sum([room.volume for room in self._room_2ds])
+
+    @property
+    def is_above_ground(self):
+        """Get a boolean to note if this Story is above the ground.
+
+        The story is considered above the ground if at least one of its Room2Ds
+        has an outdoor boundary condition.
+        """
+        for room in self._room_2ds:
+            for bc in room._boundary_conditions:
+                if isinstance(bc, Outdoors):
+                    return True
+        return False
+
     @property
     def min(self):
         """Get a Point2D for the min bounding rectangle vertex in the XY plane.
@@ -397,12 +412,26 @@ using-multipliers-zone-and-or-window.html
                                for room in self._room_2ds)
 
     def set_outdoor_window_parameters(self, window_parameter):
-        """Set all of the outdoor walls to have the same window parameters."""
+        """Set all of the outdoor walls to have the same window parameters.
+
+        Args:
+            window_parameter: A WindowParameter object that will be assigned to
+                all wall segments of this story's rooms that have an Outdoors
+                boundary conditions. This can also be None, to remove all
+                windows from the story.
+        """
         for room in self._room_2ds:
             room.set_outdoor_window_parameters(window_parameter)
 
     def set_outdoor_shading_parameters(self, shading_parameter):
-        """Set all of the outdoor walls to have the same shading parameters."""
+        """Set all of the outdoor walls to have the same shading parameters.
+
+        Args:
+            shading_parameter: A ShadingParameter object that will be assigned to
+                all wall segments of this story's rooms that have an Outdoors
+                boundary conditions. This can also be None, to remove all
+                shades from the story.
+        """
         for room in self._room_2ds:
             room.set_outdoor_shading_parameters(shading_parameter)
 
@@ -426,6 +455,25 @@ using-multipliers-zone-and-or-window.html
         for room in self._room_2ds:
             room.is_top_exposed = is_top_exposed
 
+    def make_underground(self):
+        """Make this Story underground by setting all Room2D segments to have Ground BCs.
+
+        Note that this method only changes the outdoor walls of the Room2Ds to have
+        Ground boundary conditions and, if the floors of the story are also in
+        contact with the ground, the set_ground_contact should be used in addition
+        to this method.
+
+        Also note that this method will throw an exception if any of the Room2Ds have
+        WindowParameters assigned to them (since Ground boundary conditions are)
+        not compatible with windows. So using the set_outdoor_window_parameters
+        method and passing None to remove all windows is often recommended
+        before running this method.
+        """
+        for room in self._room_2ds:
+            for i, bc in enumerate(room._boundary_conditions):
+                if isinstance(bc, Outdoors):
+                    room.set_boundary_condition(i, bcs.ground)
+
     def generate_grid(self, x_dim, y_dim=None, offset=1.0):
         """Get a list of gridded Mesh3D objects offset from the floors of this story.
 
@@ -514,7 +562,7 @@ using-multipliers-zone-and-or-window.html
                 floor_to_ceiling_height at which adjacent Faces will be split.
                 If None, no splitting will occur. Default: 0.01, suitable for
                 objects in meters.
-        
+
         Returns:
             A list of honeybee Rooms that represent the Story.
         """
@@ -569,6 +617,14 @@ using-multipliers-zone-and-or-window.html
             base['user_data'] = self.user_data
         return base
 
+    @property
+    def to(self):
+        """Story writer object.
+
+        Use this method to access Writer class to write the story in other formats.
+        """
+        return writer
+
     def __copy__(self):
         new_s = Story(self.identifier, tuple(room.duplicate() for room in self._room_2ds),
                       self._floor_to_floor_height, self._multiplier)
